# Getting started

To get started with Pykka, the following sections will take you through:

- [The actor model](model.md) - learn about the actor model concepts and rules
  that Pykka is based on.
- [Message-passing actors](actors.md) - learn how to create, start, and stop
  plain message-passing actors.
- [Actor proxies](proxies.md) - learn how to use actor proxies to interact with
  actors in a convenient way.
